@@ -1,4 +1,4 @@
-class Object:
+class SpotifyObject:
 	'''
 	Represents a generic Spotify Object.
 	
@@ -27,10 +27,16 @@ class Object:
 	def type(self):
 		return self._type
 
+	def __eq__(self, other):
+		return self.id == other.id
+
+	def __ne__(self, other):
+		return not self.__eq__(other)
+
 	def __repr__(self):
-		repr_str = self.__class__.__name__
-		if self.id:
-			repr_str += ' id=\'{}\''.format(self.id)
-		if self.name:
-			repr_str += ' name=\'{}\''.format(self.name)
-		return '<{}>'.format(repr_str)
+		repr = self.__class__.__name__
+		if self.id is not None:
+			repr += ' id=\'{}\''.format(self.id)
+		if self.name is not None:
+			repr += ' name=\'{}\''.format(self.name)
+		return '<%s>' % repr
